resource "kubernetes_deployment" "aws_cluster_autoscaler_deployment" {
  metadata {
    name      = "aws-cluster-autoscaler"
    namespace = "kube-system"

    labels {
      app = "aws-cluster-autoscaler"
    }
  }

  spec {
    replicas = 1

    selector {
      match_labels {
        app      = "aws-cluster-autoscaler"
        instance = "aws-cluster-autoscaler-deploy"
      }
    }

    template {
      metadata {
        labels {
          app      = "aws-cluster-autoscaler"
          instance = "aws-cluster-autoscaler-deploy"
        }

        annotations {
          "iam.amazonaws.com/role" = "eks-cluster-autoscaler"
        }
      }

      spec {
        service_account_name             = "cluster-autoscaler-svc-acc"
        termination_grace_period_seconds = 60

        volume {
          name = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"
          name = "autoscaler-ssl-volume"

          secret {
            secret_name = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"
          }
        }

        container {
          image             = "k8s.gcr.io/cluster-autoscaler:v1.13.1"
          name              = "cluster-autoscaler-container"
          image_pull_policy = "IfNotPresent"
          args              = ["./cluster-autoscaler", "--cloud-provider=aws", "--node-group-auto-discovery=asg:tag=k8s.io/cluster-autoscaler/enabled", "--skip-nodes-with-local-storage=false", "--stderrthreshold=info", "--expander=least-waste", "--v=4"]

          volume_mount {
            mount_path = "/var/run/secrets/kubernetes.io/serviceaccount"
            name       = "${kubernetes_service_account.cluster_autoscaler_service_account.default_secret_name}"
            read_only  = true

            mount_path = "/etc/ssl/certs/"
            name       = "autoscaler-ssl-volume"
            read_only  = true
          }

          liveness_probe {
            http_get {
              path = "/health"
              port = 8085
            }
          }

          port {
            container_port = 8085
          }
        }
      }
    }
  }
}

resource "kubernetes_service" "cluster_autoscale_service" {
  metadata {
    name = "cluster-autoscaler"
  }

  spec {
    port {
      port        = 8085
      protocol    = "TCP"
      target_port = 8085
    }

    selector {
      app = "aws-cluster-autoscaler"
    }

    type = "ClusterIP"
  }
}
